@@ -5,39 +5,13 @@ from json import dumps , loads
 from time import time
 from random import randint , choice
 from rubpy.tools import Tools
+from rubpy.createMethod import createMethod
 
 __version__ : str = '3.0.0'
 __author__ : str = 'Shayan Heidari'
 __copyright__ : str = 'CopyRight 2022'
 
-class createMethod(object):
-	''' This class is for creating and
-	returning methods to send requests
-	to the Rubik's server '''
-	def __init__(self:str , auth:str) -> int:
-		self.auth : str = auth
-		self.enc : str = Encryption(auth)
-		self.web : str = { "app_name"    : "Main", "app_version" : "4.0.7", "platform"    : "Web", "package"     : "web.rubika.ir", "lang_code"   : "fa" } #   rubika web client
-	
-	async def createMethod(self , Type:int , Method:str , data:dict):
-		'''This function is for
-		creating data to send
-		a request to the Rubik's server.'''
-		if Type == 4:
-			...
-		else:
-			if Type == 5:
-				return dumps(
-				{"api_version" : "5",
-				"auth" : self.auth,
-				"data_enc" : self.enc.encrypt(
-				dumps({
-				"method" : Method,
-				"input" : data,
-				"client" : self.web
-				}))}).encode()
-	
-	
+
 class Rubika(object):
 	def __init__(self : str , auth : str , displayWelcome : bool = True) -> int:
 		if displayWelcome: 
@@ -61,8 +35,8 @@ class Rubika(object):
 		receiving the latest messages
 		that have been sent to your account...'''
 		data : str = await self.Method.createMethod(
-		5 
-		, 'getChatsUpdates', 
+		5 ,
+		'getChatsUpdates', 
 		{"state" : str(round(time() - 200))}
 		)
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get('data').get('chats')
@@ -93,16 +67,23 @@ class Rubika(object):
 		for check in mode:
 			if check in text:
 				metadata : list = self.Tool.textAnalysis(text)
-				Input['metadata'] = {'meta_data_parts' : metadata}
+				Input['metadata'] = {'meta_data_parts' : metadata[0]}
+				Input['text'] = metadata[1]
 				break
-		data : dict = await self.Method.createMethod(
-		5 
-		, 'sendMessage', 
-		{
-			Input
-		})
+		data : dict = await self.Method.createMethod(5 , 'sendMessage', Input)
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
 
+	async def deleteMessages(self , chat_id : str , messages_id : list) -> dict:
+		data : str = await self.Method.createMethod(
+		5 ,
+		"deleteMessages",
+		{
+			"object_guid" : chat_id,
+			"message_ids" : messages_id,
+			"type" : "Global"
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get('data').get('chats')
+
 	async def editMessage(self , chat_id : str , message_id : str , text : str , metaData = None) -> dict:
 		'''This method is for editing messages and working with this method is very simple; Enter the chat ID in the first argument, the message ID in the second argument, and the new text in the third argument...'''
 		Input : dict = {
@@ -114,15 +95,12 @@ class Rubika(object):
 		for check in mode:
 			if check in text:
 				metadata : list = self.Tool.textAnalysis(text)
-				Input['metadata'] = {'meta_data_parts' : metadata}
+				Input['metadata'] = {'meta_data_parts' : metadata[0]}
+				Input['text'] = metadata[1]
+				break
 		if metaData != None:
 			Input['metadata'] = {'meta_data_parts' : metaData}
-		data : dict = await self.Method.createMethod(
-		5 
-		, 'editMessage', 
-		{
-			Input
-		})
+		data : dict = await self.Method.createMethod(5 , 'editMessage', Input)
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
 
 	async def banGroupMember(self : str , group_guid : str , user_guid : str ,) -> dict:
@@ -134,15 +112,66 @@ class Rubika(object):
 		the second argument.'''
 		# bot.banGroupMember('Group Guid' , 'User Guid')
 		data : str = await self.Method.createMethod(
-			5 
-			, 'banGroupMember', 
+			5 ,
+			'banGroupMember', 
 			{
 			'action' : 'Set',
 			'group_guid' : group_guid,
 			'member_guid' : user_guid
 		})
 		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
-	
+
+	async def forwardMessages(self , from_guid : str , messages_id : list , to_guid : str) -> dict:
+		data : str = await self.Method.createMethod(
+		5 ,
+		"forwardMessages",
+		{
+			"from_object_guid" : from_guid,
+			"message_ids": messages_id,
+			"rnd": f"{randint(100000,999999999)}",
+			"to_object_guid": to_guid
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
+
+	async def getGroupInfo(self , group_guid : str) -> dict:
+		data : str = await self.Method.createMethod(
+			5 ,
+			"getGroupInfo", 
+			{
+			'group_guid' : group_guid
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
+
+	async def getChannelInfo(self, channel_guid : str) -> dict:
+		data : str = await self.Method.createMethod(
+			5 ,
+			"getChannelInfo", 
+			{
+			'channel_guid' : channel_guid,
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc')))
+
+	async def getMessages(self , chat_id : str , middle_message_id : str) -> dict:
+		return loads(self.enc.decrypt(loads(await self.post(
+		self.url ,
+		await self.Method.createMethod(
+			5 
+			, 'getMessagesInterval', 
+			{
+			'object_guid' : chat_id,
+			'middle_message_id' : middle_message_id
+			})
+		)).get('data_enc')))
+
+	async def getGroupLink(self , group_guid : str) -> str:
+		data : str = await self.Method.createMethod(
+			5 ,
+			"getGroupLink", 
+			{
+			'group_guid' : group_guid,
+		})
+		return loads(self.enc.decrypt(loads(await self.post(self.url , data)).get('data_enc'))).get("data").get("join_link")
+
 class client(object):
 	def __init__(self : int , auth : str) -> int:
 		try:
