@@ -7,10 +7,10 @@ class Tools(object):
 	def textAnalysis(self , text : str) -> list:
 		Results : list = []
 
-		realText : str = text.replace("**","").replace("__","").replace("`","")
+		realText : str = text.replace("**","").replace("__","").replace("``","")
 		bolds : list = findall(r"\*\*(.*?)\*\*" , text)
 		italics : list = findall(r"\_\_(.*?)\_\_" , text)
-		monos :list = findall("`(.*?)`",text)
+		monos : list = findall(r"\`\`(.*?)\`\`" , text)
 
 		bResult : list = [realText.index(i) for i in bolds]
 		iResult : list = [realText.index(i) for i in italics]
@@ -37,4 +37,4 @@ class Tools(object):
 				"type" : "Mono"
 			})
 
-		return Results
\ No newline at end of file
+		return Results , realText
\ No newline at end of file
